@@ -3,13 +3,12 @@ package XML::Catalog;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
 use XML::Parser;
 use LWP::Simple;
 use URI::URL;
 use Text::ParseWords;
 
-$VERSION = '1.0.0_1';
+use version; our $VERSION = version->declare("v1.0.2");
 
 #####################################################################
 # Class variables (private)
@@ -326,6 +325,12 @@ sub delegateURI {
     $self->add_extend( $attrs{catalog} );
 }
 
+sub nextCatalog {
+    my ( $p, $elem, %attrs ) = @_;
+    my $self = $p->{XMLCatalog};
+    $self->add_extend( $attrs{catalog} );
+}
+
 sub system {
     my ( $p, $elem, %attrs ) = @_;
     my $self = $p->{XMLCatalog};
@@ -469,9 +474,11 @@ Error checking leaves much to be desired.
 =head1 AUTHOR
 
 Current Author:
+
 	Jeff Fearn E<lt>jfearn@cpan.orgE<gt>.
 
 Former Authors:
+
 	Eric Bohlman E<lt>ebohlman@netcom.comE<gt>.
 
 =head1 COPYRIGHT
